
import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
SECRET_KEY = 'test'

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'admincolors'
]

ROOT_URLCONF = 'admincolors.tests.app.urls'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

ADMIN_COLORS = [
    ('Test', 'test.css')
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'admincolors.context_processors.admin_theme'
            ],
        },
    },
]



from django import template

register = template.Library()


@register.inclusion_tag('admincolors/templatetags/breadcrumbs.html')
def colors_breadcrumbs(theme, themes):
    return {
        'themes': themes,
        'theme': theme
    }


@register.inclusion_tag('admincolors/templatetags/scripts.html')
def colors_scripts():
    return {}


@register.inclusion_tag('admincolors/templatetags/styles.html')
def colors_styles(theme):
    return {
        'theme': theme
    }



from django.conf import settings
from django.urls import reverse


def admin_theme(request):
    context = {}
    if request.path.startswith(reverse('admin:index')):
        context.update({
            'theme': request.COOKIES.get('theme', None)
        })
        if getattr(settings, 'ADMIN_COLORS', None):
            context.update({
                'themes': [
                    ('Default', ''),
                ] + settings.ADMIN_COLORS
            })
    return context



from admincolors.templatetags.admincolors import register
from admincolors.templatetags.admincolors import colors_breadcrumbs
from admincolors.templatetags.admincolors import colors_scripts
from admincolors.templatetags.admincolors import colors_styles
from django.template import engines
from django.template.loader import render_to_string
from django.test import TestCase


class TestTemplateTags(TestCase):

    def setUp(self):
        self.engine = engines['django']

    def test_colors_breadcrumbs(self):
        fn_input = ('test1', [('Test1', 'test1.css'), ('Test2', 'test2.css')])
        self.assertTrue('colors_breadcrumbs' in register.tags)
        self.assertEqual(
            colors_breadcrumbs(*fn_input), {
                'theme': fn_input[0], 'themes': fn_input[1]
            }
        )

    def test_colors_scripts(self):
        self.assertTrue('colors_scripts' in register.tags)
        self.assertEqual(
            colors_scripts(),
            {}
        )

    def test_colors_styles(self):
        fn_input = ('test', )
        context = {'theme': fn_input[0]}
        self.assertTrue('colors_styles' in register.tags)
        self.assertEqual(
            colors_styles(*fn_input), context
        )

    def test_breadcrumbs_render(self):
        context = {
            'theme': 'test1',
            'themes': [
                ('Test1', 'test1.css'),
                ('Test2', 'test2.css'),
                ('Test3', 'test3.css')
            ]
        }
        template = self.engine.from_string(
            '{% load admincolors %}{% colors_breadcrumbs theme themes %}'
        )
        self.assertEqual(
            template.render(context),
            render_to_string(
                'admincolors/templatetags/breadcrumbs.html', context
            )
        )
        self.assertEqual(template.render({'theme': context['theme']}), '\n')
        self.assertEqual(template.render(), '\n')

    def test_scripts_render(self):
        self.assertEqual(
            self.engine.from_string(
                '{% load admincolors %}{% colors_scripts %}'
            ).render(),
            render_to_string('admincolors/templatetags/scripts.html')
        )

    def test_styles_render(self):
        context = {
            'theme': 'test1',
        }
        template = self.engine.from_string(
            '{% load admincolors %}{% colors_styles theme %}'
        )
        self.assertEqual(
            template.render(context),
            render_to_string(
                'admincolors/templatetags/styles.html', context
            )
        )
        self.assertEqual(template.render(), render_to_string(
            'admincolors/templatetags/styles.html'
        ))



from admincolors.context_processors import admin_theme
from django.test import RequestFactory
from django.test import TestCase


class TestContextProcessors(TestCase):

    def setUp(self):
        self.request = RequestFactory().get('/admin/')
        self.request.COOKIES['theme'] = 'test.css'

    def test_admin_theme(self):
        context = admin_theme(self.request)
        self.assertEqual(context, {
            'theme': 'test.css', 'themes': [
                ('Default', ''),
                ('Test', 'test.css')
            ]
        })



from admincolors.apps import AdminColorsConfig
from django.test import TestCase


class TestAdminColorsConfig(TestCase):

    def test_name(self):
        self.assertEqual(
            AdminColorsConfig.name,
            'admincolors'
        )



from admincolors.site import AdminColorsSite
from django.test import TestCase


class TestAdminColorsSite(TestCase):

    def setUp(self):
        self.site = AdminColorsSite(name='test')

    def test_index_template(self):
        self.assertEqual(
            self.site.index_template,
            'admincolors/index.html'
        )



from setuptools import find_packages, setup
import os

version = '0.1.0'

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-admin-colors',
    version=version,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    license='MIT License',
    description='Customizable Django admin themes',
    long_description=README,
    url='https://github.com/victorfsf/django-admin-colors',
    author='Victor Ferraz',
    author_email='victorfsf.dev@gmail.com',
    keywords=[
        'django',
        'django-admin',
        'python3',
        'python3.6',
        'colors',
        'themes',
        'django-admin-colors',
        'django-admin-themes'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
